From: Alexander Schmidt <alexs@linux.vnet.ibm.com>
To: Artem.Bityutskiy@nokia.com,
"linux-mtd@lists.infradead.org" <linux-mtd@lists.infradead.org>
Subject: [PATCH] [MTD] UBI: rename major_to_info()
Date: Wed, 21 Mar 2007 17:18:50 +0100 [thread overview]
Message-ID: <200703211718.50407.alexs@linux.vnet.ibm.com> (raw)
The patch renames major_to_info() to major_to_device() to match the new
struct ubi_device.
Signed-off-by: Alexander Schmidt <alexs@linux.vnet.ibm.com>
---
drivers/mtd/ubi/cdev.c | 10 +++++-----
1 files changed, 5 insertions(+), 5 deletions(-)
--- dedekind-ubi-2.6.orig/drivers/mtd/ubi/cdev.c
+++ dedekind-ubi-2.6/drivers/mtd/ubi/cdev.c
@@ -50,12 +50,12 @@
#endif
/**
* major_to_info - get UBI device object by character device major number.
* @major: major number
*
- * This function returns a pointer to the UBI description object.
+ * This function returns a pointer to the UBI device object.
*/
-static struct ubi_device *major_to_info(int major)
+static struct ubi_device *major_to_device(int major)
{
int i;
@@ -124,7 +124,7 @@ static void revoke_exclusive(struct ubi_
static int vol_cdev_open(struct inode *inode, struct file *file)
{
struct ubi_volume_desc *desc;
- const struct ubi_device *ubi = major_to_info(imajor(inode));
+ const struct ubi_device *ubi = major_to_device(imajor(inode));
int vol_id = iminor(inode) - 1;
int mode;
@@ -660,7 +660,7 @@ static int ubi_cdev_ioctl(struct inode *
return -EPERM;
}
- ubi = major_to_info(imajor(inode));
+ ubi = major_to_device(imajor(inode));
if (IS_ERR(ubi))
return PTR_ERR(ubi);
next reply other threads:[~2007-03-21 16:19 UTC|newest]
Thread overview: 2+ messages / expand[flat|nested] mbox.gz Atom feed top
2007-03-21 16:18 Alexander Schmidt [this message]
2007-03-21 16:21 ` [PATCH] [MTD] UBI: rename major_to_info() Artem Bityutskiy
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=200703211718.50407.alexs@linux.vnet.ibm.com \
--to=alexs@linux.vnet.ibm.com \
--cc=Artem.Bityutskiy@nokia.com \
--cc=linux-mtd@lists.infradead.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -50,12 +50,12 @@
#endif
/**
- * major_to_info - get UBI device object by character device major number.
+ * major_to_device - get UBI device object by character device major number.
* @major: major number
*
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox